// Copyright 2014 Google Inc.

#import <Foundation/Foundation.h>

#import "GCKPlayerState.h"

/**
 * @file GCKPlayerInfo.h
 */

/**
 * Represents data for a single player.
 *
 * @ingroup Games
 */
GCK_EXPORT
@interface GCKPlayerInfo : NSObject

/**
 * The unique string identifier of this player.
 */
@property(nonatomic, copy, readonly) NSString *playerID;

/**
 * The current state of the player.
 */
@property(nonatomic, readonly) GCKPlayerState playerState;

/**
 * Player-specific data defined by the game. This data is persisted while the game is
 * running. Will be either an object that can be serialized to JSON
 * using NSJSONSerialization, or nil.
 */
@property(nonatomic, copy, readonly) id playerData;

/**
 * True if this player is in a connected state. A player is considered to be in a connected state if
 * the associated {@link GCKPlayerInfo#playerState} is one of {@link GCKPlayerStateAvailable},
 * {@link GCKPlayerStateReady}, {@link GCKPlayerStateIdle} or {@link GCKPlayerStatePlaying}.
 */
@property(nonatomic, readonly) BOOL isConnected;

/**
 * True if this player is was created on this sender device.
 */
@property(nonatomic, readonly) BOOL isControllable;

@end
